---
slug: /dml-overview-of-api
---

# DML operations

DML (Data Manipulation Language) operations allow you to insert, update, and delete data in a collection.

For DML operations, you can use the following APIs.

| API | Description | Documentation |
|---|---|---|
| `add()` | Inserts a new record into a collection. | [Documentation](200.add-data-of-api.md) |
| `update()` | Updates an existing record in a collection. |[Documentation](300.update-data-of-api.md)|
| `upsert()`  | Inserts a new record or updates an existing record.  |[Documentation](400.upsert-data-of-api.md)|
| `delete()`  | Deletes a record from a collection.|[Documentation](500.delete-data-of-api.md)|